@@ -82,6 +82,56 @@ def get(clusterId, descOnly=False, oplog=False):
         print('  |--Data Disk: %s (%s) %sGB' % (disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size'] ))
     print('')
 
+    # mounts
+    mounts = result.Configs.Mounts
+    print('%s (Locale: %s , Lock: %s)' % (blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock')))
+
+
+    entries = mounts.get('Entries')
+    if entries:
+        for ent in entries:
+           print('  |--%s %s %s' % (ent['Destination'], blue('<-'), green(ent['Source'])))
+
+    nas  = mounts.get('  Nas')
+    if nas:
+        if nas.get('AccessGroup'):
+            print('    AccessGroup: %s' % (','.join(nas['AccessGroup'])))
+        if nas.get('FileSystem'):
+            print('    FileSystem: %s' % (','.join(nas['FileSystem'])))
+
+    oss = mounts.get('OSS')
+    if oss:
+        if oss.get('AccessKeyId'):
+            print('    AccessKeyId: %s' % nas['AccessGroup'])
+        if oss.get('AccessKeySecret'):
+            print('    AccessKeySecret: %s' % nas['AccessKeySecret'])
+        if oss.get('AccessSecurityToken'):
+            print('    AccessSecurityToken: %s' % nas['AccessSecurityToken'])
+
+
+
+    # Networks
+    networks = result.Configs.Networks
+    if networks:
+        print('  |--Classic:')
+        if networks.get('Classic'):
+            if networks['Classic'].get('AllowIpAddress'):
+                print('     AllowIpAddress: %s' % ','.join(networks['Classic']['AllowIpAddress']))
+            if networks['Classic'].get('AllowIpAddressEgress'):
+                print('     AllowIpAddressEgress: %s' % ','.join(networks['Classic']['AllowIpAddressEgress']))
+            if networks['Classic'].get('AllowSecurityGroup'):
+                print('     AllowSecurityGroup: %s' % ','.join(networks['Classic']['AllowSecurityGroup']))
+            if networks['Classic'].get('AllowSecurityGroupEgress'):
+                print('     AllowSecurityGroupEgress: %s' % ','.join(networks['Classic']['AllowSecurityGroupEgress']))
+
+        # vpc
+        if networks.get('VPC'):
+            print('  |--VPC:')
+            for (k, v) in networks.get('VPC').items():
+                if v:
+                    print('     %s : %s' % (k, v))
+
+    print('')
 
     # notification
     if result.get('Notification').get('Topic').get('Events'):
@@ -144,6 +194,13 @@ def get(clusterId, descOnly=False, oplog=False):
         for (k,v) in ud.items():
             print('  %s : %s' % (k,v))
 
+    # env vars
+    env = result.get('EnvVars')
+    if env:
+        print('%s' % (blue('Env Vars:')))
+        for (k, v) in env.items():
+            print('  %s : %s' % (k, v))
+
 
     # print groups
     print('%s' % bold(magenta('Groups:')))
