@@ -22,9 +22,11 @@ TIMEOUT=86400
 def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None, nodes=None,
            force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
            file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None,
+           reserve_on_fail=False,
            notification_endpoint=None, notification_topic=None, notification_events=None,
            resource_type=None,
            nas_access_group=None, nas_file_system=None,
+            vpc_cidr_block = None,
            show_json=False):
 
     if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
@@ -49,6 +51,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'nodes' : nodes,
         'force': force,
         'auto_release': auto_release,
+        'reserve_on_fail': reserve_on_fail,
         'lock': lock,
         'locale': locale,
 
@@ -57,6 +60,8 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
 
         'resource_type': resource_type,
 
+
+
         'priority': priority,
 
         'docker': docker,
@@ -72,7 +77,9 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'notification_events': notification_events,
 
         'nas_access_group': nas_access_group,
-        'nas_file_system': nas_file_system
+        'nas_file_system': nas_file_system,
+
+        'vpc_cidr_block': vpc_cidr_block
 
     }
 
@@ -228,6 +235,19 @@ def fix_by_opt(desc, opt, check_cluster):
                     task_desc['AutoCluster']['Configs']={}
                 task_desc['AutoCluster']['Configs']['Disks'] = opt['disk']
 
+            if opt.get('reserve_on_fail'):
+                task_desc['AutoCluster']['ReserveOnFail'] = opt.get('reserve_on_fail')
+
+            # vpc
+            if opt.get('vpc_cidr_block') :
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs'] = {}
+                if not task_desc['AutoCluster']['Configs'].get('Networks'):
+                    task_desc['AutoCluster']['Configs']['Networks'] = {}
+                if not task_desc['AutoCluster']['Configs']['Networks'].get('VPC'):
+                    task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
+                task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = opt.get('vpc_cidr_block')
+
         if opt.get('nas_access_group'):
 
             # if not task_desc.get('ClusterId'):
@@ -410,7 +430,8 @@ def trans_file_to_job_desc(file, check_cluster):
                 # else:
                     task_desc['Mounts']['NAS']['FileSystem'] = cf.get(DEFAULT, 'nas_file_system').split(',')
 
-
+            if cf.has_option(DEFAULT, 'reserve_on_fail'):
+                task_desc['AutoCluster']['ReserveOnFail']=cf.getboolean(DEFAULT, 'reserve_on_fail')
         ###################################
 
 
@@ -470,6 +491,16 @@ def trans_file_to_job_desc(file, check_cluster):
                     task_desc['AutoCluster']['UserData'] = {}
                 extend(task_desc['AutoCluster']['UserData'], trans_user_data(cf.get(sec, 'user_data')))
 
+            # vpc
+            if cf.has_option(sec, 'vpc_cidr_block'):
+                if not task_desc['AutoCluster'].get('Configs'):
+                    task_desc['AutoCluster']['Configs'] = {}
+                if not task_desc['AutoCluster']['Configs'].get('Networks'):
+                    task_desc['AutoCluster']['Configs']['Networks'] = {}
+                if not task_desc['AutoCluster']['Configs']['Networks'].get('VPC'):
+                    task_desc['AutoCluster']['Configs']['Networks']['VPC'] = {}
+                task_desc['AutoCluster']['Configs']['Networks']['VPC']['CidrBlock'] = cf.get(sec, 'vpc_cidr_block')
+
         if cf.has_option(sec,'nas_access_group'):
             # if task_desc.get('AutoCluster'):
             #     task_desc['AutoCluster']['Configs']['Mounts']['NAS']['AccessGroup'] = cf.get(sec,'nas_access_group').split(
@@ -486,7 +517,8 @@ def trans_file_to_job_desc(file, check_cluster):
             # else:
                 task_desc['Mounts']['NAS']['FileSystem'] = cf.get(sec, 'nas_file_system').split(',')
 
-
+        if cf.has_option(sec, 'reserve_on_fail'):
+            task_desc['AutoCluster']['ReserveOnFail'] = cf.getboolean(sec, 'reserve_on_fail')
 
 
         if cf.has_option(sec,'env'):
@@ -717,10 +749,10 @@ def gen_task_desc():
         "InstanceCount": 1,
         "ClusterId": "",
         "Mounts": {
-            'NAS': {}
+            'NAS': {},
         },
         "AutoCluster": {
-
+           'ReserveOnFail': False
         },
         "MaxRetryCount": 0,
         "Parameters": {
