@@ -304,6 +304,8 @@ class Cli:
         cmd_create_cluster.option("-u, --user_data [kv_pairs]",
                                   MSG['create_cluster']['option']['user_data'],
                                   resolve=cluster_create.trans_user_data)
+
+        cmd_create_cluster.option("-e, --env [kv_pairs]", MSG['create_cluster']['option']['env'],resolve=cluster_create.trans_env)
         cmd_create_cluster.option("--disk [disk_configs]",
                                   MSG['create_cluster']['option']['disk'],
                                   resolve=cluster_create.trans_disk)
@@ -311,7 +313,8 @@ class Cli:
         cmd_create_cluster.option("--resource_type [resource_type]",
                                   MSG['create_cluster']['option']['resource_type'])
 
-        cmd_create_cluster.option("-m, --mount [kv_pairs]", MSG['create_cluster']['option']['mount'])
+        cmd_create_cluster.option("-m, --mount [kv_pairs]", MSG['create_cluster']['option']['mount'],
+                                  resolve=cluster_create.trans_mount)
         cmd_create_cluster.option("--nas_access_group [nas_access_group]",
                               MSG['create_cluster']['option']['nas_access_group'])
         cmd_create_cluster.option("--nas_file_system [nas_file_system]", MSG['create_cluster']['option']['nas_file_system'])
@@ -321,6 +324,8 @@ class Cli:
         cmd_create_cluster.option("--notification_topic [mns_topic]", MSG['create_cluster']['option']['notification_topic'])
         cmd_create_cluster.option("--notification_events [cluster_events]", MSG['create_cluster']['option']['notification_events'],
                               resolve=cluster_create.trans_notification_events)
+        cmd_create_cluster.option("--vpc_cidr_block [vpc_cidr_block]",
+                                  MSG['create_cluster']['option']['vpc_cidr_block'])
         cmd_create_cluster.option("--show_json",
                               MSG['create_cluster']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_create_cluster)
@@ -351,7 +356,20 @@ class Cli:
               2. %s uc cls-idxxx1 -n 2         # ignore group name when it is 'group' ''' % (COMMAND, CMD, CMD),
                                      func=cluster_update.update)
         cmd_update_cluster.option("-y, --yes",  MSG['update_cluster']['option']['yes'])
-        cmd_update_cluster.option("-n, --nodes <desiredVMCount>",  MSG['update_cluster']['option']['nodes'])
+        cmd_update_cluster.option("-n, --nodes [desiredVMCount]",  MSG['update_cluster']['option']['nodes'],
+                                  resolve=cluster_update.trans_nodes)
+
+        cmd_update_cluster.option("-m, --mount [kv_pairs]", MSG['update_cluster']['option']['mount'],
+                                  resolve=cluster_create.trans_mount)
+        cmd_update_cluster.option("-i, --image [imageId]", MSG['update_cluster']['option']['image'],
+                                  resolve=cluster_update.trans_image)
+        cmd_update_cluster.option("-u, --user_data [kv_pairs]",
+                                  MSG['update_cluster']['option']['user_data'],
+                                  resolve=cluster_update.trans_user_data)
+        cmd_update_cluster.option("-e, --env [kv_pairs]", MSG['update_cluster']['option']['env'],
+                                  resolve=cluster_update.trans_env)
+        cmd_update_cluster.option("--show_json",
+                                  MSG['update_cluster']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_update_cluster)
 
         ######################
@@ -528,7 +546,10 @@ class Cli:
         cmd_submit_job.option("--notification_topic [mns_topic]", MSG['submit']['option']['notification_topic'])
         cmd_submit_job.option("--notification_events [job_events]", MSG['submit']['option']['notification_events'],
                               resolve=job_submit.trans_notification_events)
+        cmd_submit_job.option("--reserve_on_fail", MSG['submit']['option']['reserve_on_fail'])
 
+        cmd_submit_job.option("--vpc_cidr_block [vpc_cidr_block]",
+                                  MSG['submit']['option']['vpc_cidr_block'])
 
         cmd_submit_job.option("--show_json",
                               MSG['submit']['option']['show_json'], visible=IS_GOD)
