@@ -39,6 +39,9 @@ def getJSON():
         "instance_type": {
             "description": 'show available instance types.'
         },
+        "resource_type": {
+            "description": 'show available resource types.'
+        },
         "event": {
             "description": 'show available events.'
         },
@@ -90,6 +93,7 @@ def getJSON():
                 'nodes': "optional, int, default: 1",
                 #'groups': "optional, format: <groupName>[:type=<instanceType>][:nodes=<instanceCount>], default:group1",
                 'description': "optional, description, string",
+                'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
                 'disk': """optional, mount system disk and a data disk(optional)Usage: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
@@ -111,6 +115,7 @@ def getJSON():
                                              and it is always using with nas_access_group and nas_file_system""",
                 'nas_access_group': 'NAS access groups',
                 'nas_file_system': 'NAS file system',
+                'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
                 'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
@@ -124,7 +129,15 @@ def getJSON():
             'description': 'update cluster, only support updating DesiredVMCount currently',
             'option': {
                 'yes': "optional, update in silent mode",
-                'nodes': "required, should be positive integer"
+                'nodes': "required, should be positive integer",
+                'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
+                'user_data': "optional, user data k-v pairs, exp: a:b,c:e",
+                'mount': """optional,mount a nas path to local file system in read/write mode, kv-pairs, multi-supported,
+        format: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+        example: nas://path/to/mount:/home/admin/dir.
+        and it is always using with nas_access_group and nas_file_system""",
+                'image': "optional, imageId, type '%s t' for more" % CMD,
+                'show_json': 'optional, just output cluster json, won\'t create a cluster, default: false'
             }
         },
         'create_job': {
@@ -216,6 +229,8 @@ def getJSON():
                 'nas_access_group': 'NAS access groups',
                 'nas_file_system': 'NAS file system',
                 'resource_type': 'optional, default "OnDemand", scope: [OnDemand|Spot]',
+                'reserve_on_fail': 'optional, won\'t release auto-cluster when job failed',
+                'vpc_cidr_block': 'CIDR, such as: 192.168.0.0/16',
                 'show_json': 'optional,just output job.json, won\'t submit a job, default: false'
             }
         },
