@@ -55,13 +55,19 @@ def __get_json():
             "description": '显示可用磁盘类型列表.'
         },
         "instance_type": {
+            "description": '显示实例类型列表.'
+        },
+        "resource_type": {
             "description": '显示资源类型列表.'
         },
+        "event": {
+            "description": '显示支持的事件.'
+        },
         "cluster": {
             "description": '获取集群列表, 获取集群详情.',
             "option": {
                 'description': '获取集群描述JSON',
-                'oplog': '显示操作日志, 获取集群详情有效'
+                'oplog': '显示操作日志, 获取集群详情有效',
             }
         },
         "job": {
@@ -104,17 +110,29 @@ def __get_json():
                 'type': "可选, instanceType, 更多信息输入 %s t 查看" % (CMD),
                 'nodes': "可选, int类型, default: 1",
                 'description': "可选, 描述信息, string",
+                'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
+                'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选, 挂载磁盘, 支持系统盘配置和一块数据盘(可选)的配置,
-                                      使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                      默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-                                      系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
-                                      举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-                                      数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
-                                      举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
-                                      (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
-                                      (运行 '%s d' 可以看到本区域支持的diskType).
+                                             使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
+                                             默认只挂载一个系统盘:类型为ephemeral,大小40GB.
+                                             系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                             举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
+                                             数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
+                                             (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
+                                             (运行 '%s d' 可以看到本区域支持的diskType).
                  """ % CMD,
+
+                'notification_events': "消息通知的事件,可以用'%s e'查看。" % CMD,
+                'notification_topic': "消息通知的Topic名称,可以在mns创建。",
+                'notification_endpoint': "消息通知的Endpoint, 可以在mns控制台查看。",
+                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+                                             如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
+                                             使用NAS挂载还需配置nas_access_group和nas_file_system""",
+                'nas_access_group': 'NAS 权限组',
+                'nas_file_system': 'NAS 文件系统',
+                'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
                 'show_json': '只显示cluster json不创建'
             }
         },
@@ -128,8 +146,16 @@ def __get_json():
             'description': '修改集群信息, 目前只支持修改期望机器数',
             'option': {
                 'yes': "可选, 不要询问直接修改",
-                'nodes': "必选, 期望修改的机器数, 必须为正整数"
+                'nodes': "必选, 期望修改的机器数, 必须为正整数",
+                'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
+                'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
+                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+        如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
+        使用NAS挂载还需配置nas_access_group和nas_file_system""",
+                'image': "可选, imageId, 更多信息输入 %s i 查看" % CMD,
+                'show_json': '只显示cluster json不创建'
             }
+
         },
         'create_job': {
             'description': '通过 JSON 创建作业',
@@ -166,11 +192,11 @@ def __get_json():
             'description': '快速提交单个任务的作业',
             'option': {
                 'cluster': """可选,可以使一个集群ID或者AutoCluster配置字符串.
-                                      默认是一个AutoCluster配置字符串: img=%s:type=%s.
-                                      你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
-                                      或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType>
-                                      (运行 '%s i' 可以列出可用的Image, 其他的可用查看官网文档)
-                                      (运行 '%s t' 可以看到本区域支持的instanceType). """ % (
+                                             默认是一个AutoCluster配置字符串: img=%s:type=%s.
+                                             你可以使用一个已经存在的集群ID(type '%s c' for more cluster id),
+                                             或者可以使用AutoCluster配置字符串, 格式: img=<imageId>:type=<instanceType>
+                                             (运行 '%s i' 可以列出可用的Image, 其他的可用查看官网文档)
+                                             (运行 '%s t' 可以看到本区域支持的instanceType). """ % (
                 IMG_ID, INS_TYPE, CMD, CMD, CMD),
                 'pack': "可选,打包指定目录下的文件,并上传到OSS, 如果没有指定这个选项则不打包不上传",
                 'priority': '可选,int类型,指定作业优先级,默认:0\n',
@@ -183,32 +209,40 @@ def __get_json():
                 'auto_release': "可选,当job运行成功(state=='Finished')后自动被释放(删除)掉",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """可选,只读模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
+                                             如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
                 'write_mount': """可选,可写模式挂载配置(任务结束后写到本地目录的文件会被上传到相应的oss_path下),
-                                      格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
-                'mount': """可选,读写模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
-                                      如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
+                                             格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
+                                             如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
+                'mount': """可选,读写模式挂载NAS配置, 格式: <nas_path>:<dir_path>[,<nas_path2>:<dir_path2>...],
+                                             如: nas://path/to/mount:/home/admin/nasdir 表示将NAS路径挂载到本地目录。
+                                             使用NAS挂载还需配置nas_access_group和nas_file_system""",
                 'docker': """可选, 使用docker镜像运行, 格式: <image_name>@<storage_oss_path>,
-                                      如: localhost:5000/myubuntu@oss://bucket/dockers/
-                                      或者: myubuntu@oss://bucket/dockers/""",
+                                             如: localhost:5000/myubuntu@oss://bucket/dockers/
+                                             或者: myubuntu@oss://bucket/dockers/""",
                 'file': """可选,使用配置文件提交作业,如果你显示指定其他选项,配置文件中的选项会被覆盖""",
                 'user_data': "可选, 用户数据, k:v 对,多个逗号隔开, 格式: k:v,k2:v2",
                 'disk': """可选,挂载磁盘, 只在使用AutoCluster时有效, 支持系统盘配置和一块数据盘(可选)的配置,
 
-                                      使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
-                                      默认只挂载一个系统盘:类型为ephemeral,大小40GB.
-                                      系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
-                                      举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
-                                      数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
-                                      举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
-                                      (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
-                                      (运行 '%s d' 可以看到本区域支持的diskType).
+                                             使用方法如: "--disk system:ephemeral:40,data:cloud:50:/home/disk1".
+                                             默认只挂载一个系统盘:类型为ephemeral,大小40GB.
+                                             系统盘配置格式: system:<cloud|ephemeral>:<40-500>,
+                                             举例: system:cloud:40, 表示系统盘挂载40GB的云盘.
+                                             数据盘配置格式: data:<cloud|ephemeral>:<5-2000>:<mount-point>,
+                                             举例: data:cloud:5:/home/disk1, 表示挂载一个5GB的云盘作为数据盘, window下只能挂载到驱动,如E盘:"data:cloud:5:E".
+                                             (注意: 数据盘使用ephemeral的时候,size取值范围限制为:[5-1024]GB).
+                                             (运行 '%s d' 可以看到本区域支持的diskType).
                         """ % CMD,
                 'lock': """OSS挂载是否支持网络文件锁。""",
                 'locale': """OSS Object挂载到本地时使用的字符集。可选范围包括GBK、GB2312-80、BIG5、UTF-8、ANSI、EUC-JP、EUC-TW、EUC-KR、SHIFT-JIS、KSC5601等。""",
+                'notification_events': "消息通知的事件,可以用'%s e'查看。" % CMD,
+                'notification_topic': "消息通知的Topic名称,可以在mns创建。",
+                'notification_endpoint': "消息通知的Endpoint, 可以在mns控制台查看。",
+                'nas_access_group': 'NAS 权限组',
+                'nas_file_system': 'NAS 文件系统',
+                'resource_type': '可选, 默认 "OnDemand(按需)", 可选范围:[OnDemand|Spot]',
+                'reserve_on_fail': '可选, 作业失败不会释放autoCluster, 便于调查问题',
+                'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
                 'show_json': '只显示json不提交作业'
-
             }
         },
         'check': {
